**robo-utils** 


Useful functions for mobile robotics 
and related applications.

This toolkit contains mapping, bounding and conversion functions\
for the development of mobile robotic units and systems that are\
frequently needed and convenient to have in one place



Installation:

$ **pip** install robo-utils


For documentation see https://robo-utils.readthedocs.io/en/latest/







